==> haskell-bv-sized-1.0.6-59-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-bv-sized.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bv-sized
version:              1.0.6
visibility:           public
id:                   bv-sized-1.0.6-BhUc4hNjR4RAGJ0MU8zxHJ
key:                  bv-sized-1.0.6-BhUc4hNjR4RAGJ0MU8zxHJ
license:              BSD-3-Clause
copyright:            Galois Inc., Ben Selfridge March 2018
maintainer:           benselfridge@galois.com
author:               Ben Selfridge
homepage:             https://github.com/GaloisInc/bv-sized
synopsis:
    a bitvector datatype that is parameterized by the vector width

description:
    This module defines a width-parameterized bitvector type and various associated operations.

category:             Bit Vectors
abi:                  3cb4ce709433b374f97613751014c870
exposed:              True
exposed-modules:
    Data.BitVector.Sized Data.BitVector.Sized.Overflow
    Data.BitVector.Sized.Signed Data.BitVector.Sized.Unsigned

hidden-modules:
    Data.BitVector.Sized.Internal Data.BitVector.Sized.Panic

import-dirs:          /usr/lib/ghc-9.4.8/site-local/bv-sized-1.0.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/bv-sized-1.0.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/bv-sized-1.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bv-sized
hs-libraries:         HSbv-sized-1.0.6-BhUc4hNjR4RAGJ0MU8zxHJ
depends:
    base-4.17.2.1 bitwise-1.0.0.1-HjBCsPfE1RDHcb0TMBjXU5
    bytestring-0.11.5.3 deepseq-1.4.8.0
    panic-0.4.0.1-Jq9VAg5hh1m6c8kWsB4pox
    parameterized-utils-2.1.10.0-7LSyxSOd93DLAJtjTt6RNS
    random-1.2.1.3-KpmZVmsijPULH6l5PrmXSD
    th-lift-0.8.6-HRVeiGNnDxNElRy2LmdExl

haddock-interfaces:   /usr/share/doc/haskell-bv-sized/html/bv-sized.haddock
haddock-html:         /usr/share/doc/haskell-bv-sized/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bv-sized-1.0.6-82-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-bv-sized.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bv-sized
version:              1.0.6
visibility:           public
id:                   bv-sized-1.0.6-5oEul6zt1G3JA0wtjT5LK
key:                  bv-sized-1.0.6-5oEul6zt1G3JA0wtjT5LK
license:              BSD-3-Clause
copyright:            Galois Inc., Ben Selfridge March 2018
maintainer:           benselfridge@galois.com
author:               Ben Selfridge
homepage:             https://github.com/GaloisInc/bv-sized
synopsis:
    a bitvector datatype that is parameterized by the vector width

description:
    This module defines a width-parameterized bitvector type and various associated operations.

category:             Bit Vectors
abi:                  a6e611245a46dec3a9f4e6ee314b9880
exposed:              True
exposed-modules:
    Data.BitVector.Sized Data.BitVector.Sized.Overflow
    Data.BitVector.Sized.Signed Data.BitVector.Sized.Unsigned

hidden-modules:
    Data.BitVector.Sized.Internal Data.BitVector.Sized.Panic

import-dirs:          /usr/lib/ghc-9.4.8/site-local/bv-sized-1.0.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/bv-sized-1.0.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/bv-sized-1.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bv-sized
hs-libraries:         HSbv-sized-1.0.6-5oEul6zt1G3JA0wtjT5LK
depends:
    base-4.17.2.1 bitwise-1.0.0.1-5sbulqu7ULYJTjDeCbzVOu
    bytestring-0.11.5.3 deepseq-1.4.8.0
    panic-0.4.0.1-3QvhbYIlGoL4pBeY3qhGHr
    parameterized-utils-2.1.10.0-GzuSb1xDXv4DyqINT4dPm9
    random-1.2.1.3-KY8hXIsRO0nEsZvihu4hBT
    th-lift-0.8.6-HRVeiGNnDxNElRy2LmdExl

haddock-interfaces:   /usr/share/doc/haskell-bv-sized/html/bv-sized.haddock
haddock-html:         /usr/share/doc/haskell-bv-sized/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
